searchData={"items":[{"type":"module","title":"KeywordValidator","doc":"Functions for validating keyword lists.\n\nThe main function in this module is `validate/2`, which allows developers to\nvalidate a keyword list against a given schema.\n\nA schema is a keyword list that matches the keys for the keyword list.\nThe values in the schema represent the options available during validation.\n\n    iex> KeywordValidator.validate([foo: :bar], [foo: [is: :atom]])\n    {:ok, [foo: :bar]}\n\n    iex> KeywordValidator.validate([foo: :bar], [foo: [is: :integer]])\n    {:error, [foo: [\"must be an integer\"]]}","ref":"KeywordValidator.html"},{"type":"type","title":"KeywordValidator.base_schema/0","doc":"A keyword base schema.","ref":"KeywordValidator.html#t:base_schema/0"},{"type":"type","title":"KeywordValidator.custom_validator/0","doc":"Custom validation logic for key values.","ref":"KeywordValidator.html#t:custom_validator/0"},{"type":"function","title":"KeywordValidator.docs/1","doc":"Builds documentation for a given schema.\n\nThis can be used to inject documentation in your docstrings. For example:\n\n    @options_schema KeywordValidator.schema!([key: [type: :any, doc: \"Some option.\"]])\n\n    @doc \"Options:\\n#{KeywordValidator.docs(@options_schema)}\"\n\nThis will automatically generate documentation that includes information on\nrequired keys and default values.","ref":"KeywordValidator.html#docs/1"},{"type":"type","title":"KeywordValidator.invalid/0","doc":"An invalid keyword key.","ref":"KeywordValidator.html#t:invalid/0"},{"type":"type","title":"KeywordValidator.option/0","doc":"Individual validation options.","ref":"KeywordValidator.html#t:option/0"},{"type":"type","title":"KeywordValidator.options/0","doc":"All validation options.","ref":"KeywordValidator.html#t:options/0"},{"type":"type","title":"KeywordValidator.schema/0","doc":"A keyword schema.","ref":"KeywordValidator.html#t:schema/0"},{"type":"function","title":"KeywordValidator.schema!/1","doc":"Prepares a schema or raises an `ArgumentError` exception if invalid.\n\nA schema is a keyword list of keys and value options.\n\nThis is the preferred method of providing a validation schema as it ensures\nyour schema is valid and avoids running additional validation on each invocation.\nYou can then declare your schema as a module attribute:\n\n    @opts_schema KeywordValidator.schema!([...])\n\n    KeywordValidator.validate!(keyword, @opts_schema)","ref":"KeywordValidator.html#schema!/1"},{"type":"function","title":"Value Options - KeywordValidator.schema!/1","doc":"* `:is` - The value type associated with the key. Must be one of `t:KeywordValidator.value_is/0`. Defaults to `:any`. \n* `:default` - The default value for the key if not provided one.\n* `:required` - Boolean representing whether the key is required or not. Defaults to `false`. \n* `:custom` - A list of two-arity functions or tuples in the format `{module, function}` that serve as custom validators. The function will be given the key and value as arguments, and must return a list of string errors (or an empty list if no errors are present). Defaults to `[]`. \n* `:doc` - Documentation for the option. Defaults to `false`.","ref":"KeywordValidator.html#schema!/1-value-options"},{"type":"function","title":"Is Options - KeywordValidator.schema!/1","doc":"The following value types are available for use with the `:is` option:\n\n* `{:=, value}` - Equal to value.\n* `:any` - Any value.\n* `:atom` - An atom.\n* `{:atom, [atom]}` - Any of the provided atoms.\n* `:binary` - A binary.\n* `:bitstring` - A bitstring.\n* `:boolean` - A boolean.\n* `:float` - A float.\n* `:fun` - A function.\n* `{:fun, arity}` - A function with specified arity.\n* `{:in, [value]}` - In the list of values.\n* `:integer` - An integer.\n* `:keyword` - A keyword list.\n* `{:keyword, schema}` - A keyword with the provided schema.\n* `:list` - A list.\n* `:map` - A map.\n* `:mfa` - A module, function and args.\n* `:mod_args` - A module and args.\n* `:mod_fun` - A module and function.\n* `:mod` - A module.\n* `:number` - A number.\n* `{:one_of, [type]}` - Any one of the provided types.\n* `:pid` - A PID.\n* `:port` - A port.\n* `:struct` - A struct.\n* `{:struct, type}` - A struct of the provided type.\n* `:timeout` - A timeout (integer or `:infinite`).\n* `:tuple` - A tuple.\n* `{:tuple, size}` - A tuple of the provided size.\n* `{:tuple, tuple}` - A tuple with the provided tuple types.","ref":"KeywordValidator.html#schema!/1-is-options"},{"type":"function","title":"KeywordValidator.validate/3","doc":"Validates a keyword list using the provided schema.\n\nA schema is a keyword list (or prepared schema via `schema!/1`) - with each key\nrepresenting a key in your keyword list. The values in the schema keyword list\nrepresent the options available for validation.\n\nIf the validation passes, we are returned a two-item tuple of `{:ok, keyword}`.\nOtherwise, returns `{:error, invalid}` - where `invalid` is a keyword list of errors.","ref":"KeywordValidator.html#validate/3"},{"type":"function","title":"Schema - KeywordValidator.validate/3","doc":"Please see `schema!/1` for options available when building schemas.","ref":"KeywordValidator.html#validate/3-schema"},{"type":"function","title":"Options - KeywordValidator.validate/3","doc":"* `:strict` - Boolean representing whether extra keys will become errors. Defaults to `true`.","ref":"KeywordValidator.html#validate/3-options"},{"type":"function","title":"Examples - KeywordValidator.validate/3","doc":"iex> KeywordValidator.validate([foo: :foo], [foo: [is: :atom, required: true]])\n    {:ok, [foo: :foo]}\n\n    iex> KeywordValidator.validate([foo: :foo], [bar: [is: :any]])\n    {:error, [foo: [\"is not a valid key\"]]}\n\n    iex> KeywordValidator.validate([foo: :foo], [bar: [is: :any]], strict: false)\n    {:ok, []}\n\n    iex> KeywordValidator.validate([foo: :foo], [foo: [is: {:in, [:one, :two]}]])\n    {:error, [foo: [\"must be one of: [:one, :two]\"]]}\n\n    iex> KeywordValidator.validate([foo: {:foo, 1}], [foo: [is: {:tuple, {:atom, :integer}}]])\n    {:ok, [foo: {:foo, 1}]}\n\n    iex> KeywordValidator.validate([foo: [\"one\", 2]], [foo: [is: {:list, :binary}]])\n    {:error, [foo: [\"must be a list of type :binary\"]]}\n\n    iex> KeywordValidator.validate([foo: %Foo{}], [foo: [is: {:struct, Bar}]])\n    {:error, [foo: [\"must be a struct of type Bar\"]]}\n\n    iex> KeywordValidator.validate([foo: \"foo\"], [foo: [is: :any, custom: [fn key, val -> [\"some error\"] end]]])\n    {:error, [foo: [\"some error\"]]}","ref":"KeywordValidator.html#validate/3-examples"},{"type":"function","title":"KeywordValidator.validate!/3","doc":"The same as `validate/2` but raises an `ArgumentError` exception if invalid.","ref":"KeywordValidator.html#validate!/3"},{"type":"function","title":"Example - KeywordValidator.validate!/3","doc":"iex> KeywordValidator.validate!([foo: :bar], [foo: [is: :atom, required: true]])\n    [foo: :foo]\n\n    iex> KeywordValidator.validate!([foo: \"bar\"], [foo: [is: :atom, required: true]])\n    ** (ArgumentError) Invalid keyword given.\n\n    Keyword:\n\n    [foo: \"bar\"]\n\n    Invalid:\n\n    foo: [\"must be an atom\"]","ref":"KeywordValidator.html#validate!/3-example"},{"type":"type","title":"KeywordValidator.value_is/0","doc":"Various value `:is` options.","ref":"KeywordValidator.html#t:value_is/0"},{"type":"type","title":"KeywordValidator.value_opt/0","doc":"Individual value options.","ref":"KeywordValidator.html#t:value_opt/0"},{"type":"type","title":"KeywordValidator.value_opts/0","doc":"All value options.","ref":"KeywordValidator.html#t:value_opts/0"},{"type":"extras","title":"KeywordValidator","doc":"# KeywordValidator\n\n[![Build Status](https://travis-ci.org/nsweeting/keyword_validator.svg?branch=master)](https://travis-ci.org/nsweeting/keyword_validator)\n[![StatBuffer Version](https://img.shields.io/hexpm/v/keyword_validator.svg)](https://hex.pm/packages/keyword_validator)\n\nKeywordValidator provides a simple interface to validate keyword lists in Elixir.","ref":"readme.html"},{"type":"extras","title":"Installation - KeywordValidator","doc":"The package can be installed by adding `keyword_validator` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:keyword_validator, \"~> 2.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Documentation - KeywordValidator","doc":"Please see [HexDocs](https://hexdocs.pm/keyword_validator) for additional documentation.","ref":"readme.html#documentation"},{"type":"extras","title":"Getting Started - KeywordValidator","doc":"To begin validating, we must first create a schema that defines the rules for our\nkeyword list.\n\nA schema is a simple keyword list with each value representing the options available for validation.\n\nIf the validation passes, we are returned a valid keyword list.\n\n```elixir\niex> keyword = [foo: :foo, bar: \"one\"]\niex> schema = [\n  foo: [is: :atom, required: true],\n  bar: [is: {:in, [\"one\", \"two\", \"three\"]}]\n]\niex> KeywordValidator.validate(keyword, schema)\n{:ok, [foo: :foo, bar: \"one\"]}\n```\n\nTo avoid additional schema validation - define your schemas as module attributes.\n\n```\n@opts_schema KeywordValidator.schema!([foo: [is: :integer]])\n```\n\nIf validation fails on any of the keys, a keyword list of the invalid entries and the\nassociated errors is returned.\n\n```elixir\niex> keyword = [foo: \"foo\", bar: \"bar\"]\niex> schema = [\n  foo: [is: :atom, required: true],\n  bar: [is: {:in, [\"one\", \"two\", \"three\"]}]\n]\niex> KeywordValidator.validate(keyword, schema)\n{:error, [bar: [\"must be one of: [\\\"one\\\", \\\"two\\\", \\\"three\\\"]\"], foo: [\"must be a binary\"]]}\n```\n\nWe can optionally use the `KeywordValidator.validate!/2` function as well - which will raise\nan error that describes the invalid key entries.\n\n```elixir\n** (ArgumentError) Invalid keyword given.\n\nKeyword:\n\n[foo: :foo, bar: :bar]\n\nInvalid:\n\nbar: [\"must be one of: [:one, :two, :three]\"]\nfoo: [\"must be a binary\"]\n```\n\nTo view all the available validation options, please check out the [relevant documentation](https://hexdocs.pm/keyword_validator/KeywordValidator.html#validate/2).\n\nYou can optionally generate documentation from your schemas.\n\n```\n@doc \"\"\"\nThis is a function.","ref":"readme.html#getting-started"},{"type":"extras","title":"Options - KeywordValidator","doc":"#{KeywordValidator.docs(@opts_schema)}\n\"\"\"\ndef my_function(opts) do\n  ...\nend\n```","ref":"readme.html#options"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}